;; Generated package description from external-completion.el  -*- no-byte-compile: t -*-
(define-package "external-completion" "0.1.0.20240616.203826" "Let external tools control completion style" 'nil :commit "f18a915690c48119daaecf5b8684c46129496866" :url "https://elpa.gnu.org/packages/external-completion.html" :authors '(("Stefan Monnier" . "monnier@iro.umontreal.ca")) :maintainer '("João Távora" . "joaotavora@gmail.com"))
